Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1112)

Unified Diff: webrtc/modules/audio_coding/codecs/audio_encoder.h

Issue 1764583003: Renamed new EncodeInternal to EncodeImpl to ensure proper backwards compatibility. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Clarified doc comments in AudioEncoder. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_coding/codecs/audio_encoder.h
diff --git a/webrtc/modules/audio_coding/codecs/audio_encoder.h b/webrtc/modules/audio_coding/codecs/audio_encoder.h
index 8da7ebd728cc094eaf01df23cabb08377e639bef..3fdee259ce7735567013f052d634e4175661a734 100644
--- a/webrtc/modules/audio_coding/codecs/audio_encoder.h
+++ b/webrtc/modules/audio_coding/codecs/audio_encoder.h
@@ -89,7 +89,7 @@ class AudioEncoder {
// NumChannels() samples). Multi-channel audio must be sample-interleaved.
// The encoder appends zero or more bytes of output to |encoded| and returns
// additional encoding information. Encode() checks some preconditions, calls
// EncodeInternal() which does the actual work, and then checks some
// postconditions.
EncodedInfo Encode(uint32_t rtp_timestamp,
rtc::ArrayView<const int16_t> audio,
@@ -110,12 +110,12 @@ class AudioEncoder {
size_t max_encoded_bytes,
uint8_t* encoded);
- // Deprecated interface of EncodeInternal (also bug 5591). May incur a copy.
+ // Deprecated interface EncodeInternal (see bug 5591). May incur a copy.
// Subclasses implement this to perform the actual encoding. Called by
// Encode(). By default, this is implemented as a call to the newer
// EncodeInternal() that accepts an rtc::Buffer instead of a raw pointer.
// That version is protected, so see below. At least one of the two
// interfaces of EncodeInternal _must_ be implemented by a subclass.
virtual EncodedInfo EncodeInternal(
uint32_t rtp_timestamp,
rtc::ArrayView<const int16_t> audio,
@@ -163,12 +163,12 @@ class AudioEncoder {
protected:
// Subclasses implement this to perform the actual encoding. Called by
// Encode(). For compatibility reasons, this is implemented by default as a
- // call to the older version of EncodeInternal(). At least one of the two
- // interfaces of EncodeInternal _must_ be implemented by a subclass.
- // Preferably this one.
- virtual EncodedInfo EncodeInternal(uint32_t rtp_timestamp,
- rtc::ArrayView<const int16_t> audio,
- rtc::Buffer* encoded);
+ // call to the older interface EncodeInternal(). At least one of
+ // EncodeInternal or EncodeImpl _must_ be implemented by a
+ // subclass. Preferably this one.
+ virtual EncodedInfo EncodeImpl(uint32_t rtp_timestamp,
+ rtc::ArrayView<const int16_t> audio,
+ rtc::Buffer* encoded);
};
} // namespace webrtc
#endif // WEBRTC_MODULES_AUDIO_CODING_CODECS_AUDIO_ENCODER_H_
@@ -89,7 +89,7 @@ class AudioEncoder {
// The encoder appends zero or more bytes of output to |encoded| and returns
// additional encoding information. Encode() checks some preconditions, calls
- // EncodeInternal() which does the actual work, and then checks some
+ // EncodeImpl() which does the actual work, and then checks some
// postconditions.
EncodedInfo Encode(uint32_t rtp_timestamp,
@@ -110,12 +110,12 @@ class AudioEncoder {
// Subclasses implement this to perform the actual encoding. Called by
// Encode(). By default, this is implemented as a call to the newer
- // EncodeInternal() that accepts an rtc::Buffer instead of a raw pointer.
- // That version is protected, so see below. At least one of the two
- // interfaces of EncodeInternal _must_ be implemented by a subclass.
+ // EncodeImpl() that accepts an rtc::Buffer instead of a raw pointer.
+ // That version is protected, so see below. At least one of EncodeInternal
+ // or EncodeImpl _must_ be implemented by a subclass.
virtual EncodedInfo EncodeInternal(
uint32_t rtp_timestamp,
« no previous file with comments | « webrtc/modules/audio_coding/acm2/rent_a_codec_unittest.cc ('k') | webrtc/modules/audio_coding/codecs/audio_encoder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698